@@ -1,6 +1,6 @@
 from enum import Enum
 import random
-import ML
+import RockPaperScissorsFullGame.ML as ML
 
 
 #Denotes instances of Item (plays) with values assigned to them.
